==> SimEngine_1.0.0.tar.gz: SimEngine/README.md <==
<!-- badges: start -->
  ![GitHub R package version](https://img.shields.io/github/r-package/v/Avi-Kenny/SimEngine)
  ![GitHub](https://img.shields.io/github/license/Avi-Kenny/SimEngine)
  [![R-CMD-check](https://github.com/Avi-Kenny/SimEngine/actions/workflows/R-CMD-check.yml/badge.svg)](https://github.com/Avi-Kenny/SimEngine/actions/workflows/R-CMD-check.yml)
  [![Codecov test coverage](https://codecov.io/gh/Avi-Kenny/SimEngine/branch/master/graph/badge.svg)](https://codecov.io/gh/Avi-Kenny/SimEngine?branch=master)
<!-- badges: end -->


# SimEngine <img src='man/figures/logo.png' align="right" height="150" />

An open-source framework for statistical simulations in R

## Overview

**SimEngine** is an open-source R package for structuring, maintaining, running, and debugging statistical simulations on both local and cluster-based computing environments. Emphasis is placed on thorough documentation and scalability.

## Installation

The latest stable version of **SimEngine** can be installed from CRAN using `install.packages()`. The current development version can be installed using `devtools::install_github()`:

```R
install.packages("SimEngine")
devtools::install_github(repo="Avi-Kenny/SimEngine")
```

## Documentation

The full package documentation can be found at [https://avi-kenny.github.io/SimEngine/](https://avi-kenny.github.io/SimEngine/). All of the CRAN documentation (i.e. the function reference and vignettes) can also be found here.

## Bugs reports and feature requests

To submit a bug report or request a new feature, please submit a new [GitHub Issue](https://github.com/Avi-Kenny/SimEngine/issues).

==> SimEngine_1.1.0.tar.gz: SimEngine/README.md <==
<!-- badges: start
  ![GitHub R package version](https://img.shields.io/github/r-package/v/Avi-Kenny/SimEngine) -->
  [![CRAN status](https://www.r-pkg.org/badges/version/SimEngine)](https://CRAN.R-project.org/package=SimEngine)
  ![GitHub](https://img.shields.io/github/license/Avi-Kenny/SimEngine)
  [![R-CMD-check](https://github.com/Avi-Kenny/SimEngine/actions/workflows/R-CMD-check.yml/badge.svg)](https://github.com/Avi-Kenny/SimEngine/actions/workflows/R-CMD-check.yml)
  [![Codecov test coverage](https://codecov.io/gh/Avi-Kenny/SimEngine/branch/master/graph/badge.svg)](https://app.codecov.io/gh/Avi-Kenny/SimEngine?branch=master)
  [![](https://cranlogs.r-pkg.org/badges/SimEngine)](https://CRAN.R-project.org/package=SimEngine)
<!-- badges: end -->


# SimEngine <img src='man/figures/logo.png' align="right" height="150" />

A modular framework for statistical simulations in R

## Overview

**SimEngine** is an open-source R package for structuring, maintaining, running, and debugging statistical simulations on both local and cluster-based computing environments. Emphasis is placed on thorough documentation and scalability.

## Installation

The latest stable version of **SimEngine** can be installed from CRAN using `install.packages()`. The current development version can be installed using `devtools::install_github()`:

```R
install.packages("SimEngine")
devtools::install_github(repo="Avi-Kenny/SimEngine")
```

## Documentation

The full package documentation can be found at [https://avi-kenny.github.io/SimEngine/](https://avi-kenny.github.io/SimEngine/). All of the CRAN documentation (i.e. the function reference and vignettes) can also be found here.

## Bugs reports and feature requests

To submit a bug report or request a new feature, please submit a new [GitHub Issue](https://github.com/Avi-Kenny/SimEngine/issues).
